% 
% Dynamic analysis of an Anagallis root system where the parameters are
% estimated based on a drawing by L. Kutschera 1960, p. 405. 
%
% Copyright 2008-2012 Daniel Leitner. See license.txt for details.
%
clear all

% root system definition
p{1}.name = 'tap root';
p{1}.r = 4; 
p{1}.lb = 1; 
p{1}.la = 1.2;
p{1}.ln = 0.8;
p{1}.nob = 40; 
p{1}.a = 0.05; 
p{1}.theta = 0;
p{1}.color = [110/255,100/255,50/255];
p{1}.tropism = [1,4,90*pi/180];  % gravitropism
p{1}.dx = 0.25;
p{1}.successor = 2;
p{2}.name = '1st order laterals';
p{2}.r = [1.5,0.15]; 
p{2}.lb = [0.4,0.1]; 
p{2}.la = [0.8,0.2];
p{2}.ln = [0.5,0.1]; 
p{2}.nob = [14,10];
p{2}.a = 0.03;
p{2}.theta = [70*pi/180, 3*pi/180];
p{2}.color = [140/255,125/255,40/255];
p{2}.tropism = [0,2,30*pi/180]; % plagiotropism
p{2}.dx = 0.1;
p{2}.successor = 3;
p{3}.name = '2nd order laterals';
p{3}.r = [2;0.2] ;
p{3}.lb = [0.1,0.01];               
p{3}.la = [0.1,0.01];         
p{3}.ln = 0.24;  
p{3}.nob = [2,2];            
p{3}.a = 0.02; 
p{3}.theta = [68*pi/180, 3*pi/180];
p{3}.color = [160/255,150/255,30/255];
p{3}.tropism = [1,2,45*pi/180]; % gravitropism
p{3}.dx = 0.1;
p{3}.successor = 4;
p{4}.name = '3rd order laterals';
p{4}.r  = [2, 0.2];                      
p{4}.la  = [0.4, 0.03];                   
p{4}.a  = 0.02;                
p{4}.theta = [68*pi/180, 3*pi/180];  
p{4}.color = [200/255,200/255,10/255];  
p{4}.tropism = [0,0,18*pi/180]; % no tropism (since N=0)                      
p{4}.dx = 0.1;

% run simulation
simtime = 15; % days
rootsystem = createRootSystem(p);
slides = simulate(rootsystem,simtime,100,true); % keep 100 intemediate results

% plot total length versus time
for i = 1 : length(slides)
    l(i) = getTotal(slides{i});
end
plot(linspace(0,simtime,length(slides)),l);
xlabel('time (days)');
ylabel('length (cm) ');

% plot last frame
figure;
plotTubes(slides{end});

makeMovie('anagallis.avi',slides,p,simtime,5);


