%
% Root system analysis: Example 1: creates a root surface concentration in
% REVs, Example 2: plot root length fractions versus depth.
% 
% See also: getMap, Example_Maize, distPot.
%
% Copyright 2008-2012 Daniel Leitner. See license.txt for details.
% 
clear all;

%
% root architecture (see Example_Maize)
%
p{1}.r = [2,0.2];
p{1}.lb = [0.7,0.07];          
p{1}.la = [15.7,1.57];                    
p{1}.ln = [0.7,0.07];                 
p{1}.nob = [50,5];  
p{1}.a = 0.03;   
p{1}.theta = 0;
p{1}.tropism = [1,1.5,15*pi/180];
p{1}.dx= 0.5;
p{1}.successor = 2;
p{2}.r = [6.4, 0.64];
p{2}.lb = [0.7, 0.07];    
p{2}.la = [2.7, 0.27];                       
p{2}.ln = [0.7, 0.07];               
p{2}.nob = [7, 0.7];                  
p{2}.a = 0.02;                
p{2}.theta = [63*pi/180,15*pi/180];       
p{2}.tropism = [1,1.5,40*pi/180];
p{2}.dx= 0.2;
p{2}.successor = 3;
p{3}.r  = [1.5,0.15];                                        
p{3}.la  = [0.2,0.02];                    
p{3}.a  = 0.01;                                 
p{3}.theta = [68*pi/180,3*pi/180];        
p{3}.tropism = [1,0,40*pi/180];
p{3}.dx= 0.2;

%
% plant pot geometry (10*1.5*38 cm3 at 49)
%
r1=10;
r2=5;
h=20;
pot = @(p) distPot(p,r1,r2,h);
for i = 1 : length(p) 
    p{i}.geometry = pot; % add geometry 
end

%
% Simulate
%
n0=5; r0=r1/2;
simtime = 40; % days
rootsystem = createRootSystem(p,n0,r0);
slides = simulate(rootsystem,simtime,10,false);

%
% plot root system
%
plotTubes(slides{end}); hold on;
X = linspace(-r1,r1,40); 
Y = linspace(-r1,r1,40);
Z = linspace(-h,0,40);
plotDistFunc(pot,X,Y,Z,[0 0 1]); % approximate the pot boundaries

% 
% Example 1: add slices with root surface concentration
%
X = linspace(-r1,r1,40); 
Y = linspace(-r1,r1,40);
Z = linspace(-h,0,20);
map = getMap(slides{end},X,Y,Z,'s');
m = permute(map,[2,1,3]);
slice(0.5*(X(1:end-1)+X(2:end)),0.5*(Y(1:end-1)+Y(2:end)),...
    0.5*(Z(1:end-1)+Z(2:end)),m,[],[],-15);

%
% Example 2: root length fraction / depth
%
X = [-inf inf];
Y = [-inf inf];
Z = linspace(-h,0,40);
[map,l] = getMap(slides{end},X,Y,Z,'l');
d = 1:size(map,3);
d(:) = map(1,1,:);
figure;
plot(d/l,Z(1:length(d)));
title('Root length distribution')
ylabel('depth (cm)');
xlabel('root length fraction');



