%
% An idealized maize root system using parameters from literature 
% with 10% standard deviation.
%
% Copyright 2008-2012 Daniel Leitner. See license.txt for details.
%
clear all;

%
% Tap root 
%
p{1}.name = 'tap root';
p{1}.r = [2,0.2];
p{1}.lb = [0.7,0.07];          
p{1}.la = [15.7,1.57];                    
p{1}.ln = [0.7,0.07];                 
p{1}.nob = [50,5];  
p{1}.a = 0.03;   
p{1}.theta = 0;
p{1}.color = [110/255,100/255,50/255];
p{1}.tropism = [1,1.5,15*pi/180];
p{1}.dx= 0.5;
p{1}.successor = 2;

%
% 1st order lateral
%
p{2}.name = '1st order lateral';
p{2}.r = [6.4, 0.64];
p{2}.lb = [0.7, 0.07];    
p{2}.la = [2.7, 0.27];                       
p{2}.ln = [0.7, 0.07];               
p{2}.nob = [7, 0.7];                  
p{2}.a = 0.02;                
p{2}.theta = [63*pi/180,15*pi/180];       
p{2}.color = [140/255,125/255,40/255];
p{2}.tropism = [1,1.5,40*pi/180];
p{2}.dx= 0.2;
p{2}.successor = 3;

%
% 2nd order lateral
%
p{3}.name = '2nd order lateral';
p{3}.r  = [1.5,0.15];                                        
p{3}.la  = [0.2,0.02];                    
p{3}.a  = 0.01;                                 
p{3}.theta = [68*pi/180,3*pi/180];        
p{3}.color = [200/255,200/255,10/255]; 
p{3}.tropism = [1,0,40*pi/180];
p{3}.dx= 0.2;

%
% Simulation
%
n0 = 1; % number of plants
r0 = 0; % planting radius
n1 = 3; % number of taproots per root crown
r1 = 3; % root crown radius

simtime = 25; % days
rootsystem = createRootSystem(p,n0,r0,n1,r1,0.5);
slides = simulate(rootsystem,simtime,10,false);

plotTubes(slides{end});


