%
% A virtual rhizotron rotated for 49 degrees. This example shows how
% gravitroism interacts with the rhizotron boundaries.
%
% See Also: Example_Rape
%
% Copyright 2008-2012 Daniel Leitner. See license.txt for details.
%
clear all;

%
% root architecture (same as in Example_Rape)
%
p{1}.r = 3; 
p{1}.lb = 0.7;
p{1}.la = 1;
p{1}.ln = [0.37, 0.25]; 
p{1}.nob = 536;
p{1}.a = 0.02;   
p{1}.theta = 0;  
p{1}.tropism = [1,5,20*pi/180]; 
p{1}.dx=0.2;
p{1}.successor = 2;
p{2}.r = 0.57; 
p{2}.la = 200; 
p{2}.a = 0.01; 
p{2}.theta = [(180-110.9)*pi/180, 19.9*pi/180]; 
p{2}.tropism = [1,1,20*pi/180];
p{2}.dx=0.2;

%
% add rhizobox geometry (10*1.5*38 cm3 at 49)
%
boxX=10; 
boxY=1.5;
boxZ=38;
delta = 49/180*pi;
dfunc = @(p) distRhizotron(p,boxX,boxY,boxZ,delta);

for i = 1 : length(p) 
    p{i}.geometry = dfunc; % add geometry 
end

%
% Simulate
%
n0=1; r0=0;
simtime = 20; % days
rootsystem = createRootSystem(p,n0,r0);
slides = simulate(rootsystem,simtime,10,false);

%
% plot root system
%
plotTubes(slides{end});

%
% plot rhizotron
%
[handle, verts, facs] = DrawCuboid([boxX;boxY;boxZ],[0;0;-boxZ/2],[0;0;-delta],[0;0;1]); %glass
alpha(handle,0.05);
axis equal;
%view(0,-49);
view(3);
xlabel('x');
ylabel('y');
zlabel('z');

% % 
% % plot soil layers
% %
% soilcol = [57,51,17];
% zz=0.25; %cm
% [handle, verts, facs] = DrawCuboid([boxX;boxY-zz;boxZ],[0;zz/2;-boxZ/2],[0;0;-delta],soilcol./255); % soil 
% alpha(handle,0.9);
% zz=0.1; %cm
% [handle, verts, facs] = DrawCuboid([boxX;boxY-zz;boxZ],[0;zz/2;-boxZ/2],[0;0;-delta],soilcol./255); % soil
% alpha(handle,0.3);

disp(' ');
disp(['length: ' num2str(getTotal(slides{1},'l')) ' cm']);
disp(['surface: ' num2str(getTotal(slides{1},'s')) ' cm2']);
disp(['volume: ' num2str(getTotal(slides{1},'v')) ' cm3']);



