function rootsystem = createRootSystem(p, nop, pr, nobr, cr, ce)
% createRootSystem: creates a number of basal roots 
%
% Parameters:
% p              :list of root system parameters
% (nop)          :number of plants per pot (default=1)
% (pr)           :planting radius (default=0)
% (nobr)         :initial number of basal roots per plant (default=1)
% (cr)           :initial radius of growth cone (default = 0)
% (ce)           :exponent (0.5 for uniform distribution, >0.5 more inner,
%                 <0.5 more outer) (default=0.5)
%
% rootsystem     :initial L-System string of the root system
%
% See also: ruleCreateRoot, completeParams.
%
% Copyright 2008-2012 Daniel Leitner & Andrea Schnepf. See license.txt for details.
%     
if (nargin<2)
    nop = 1;
end

if (nargin<3)
    pr = 0;
end

if (nargin<4)
    nobr = 1;
end

if (nargin<5) 
    cr = 0;
end

if (nargin<6) 
    ce = 0.5;
end

%
% check and complete parameter set
%
p = completeParams(p);

%
% set up one 0-order root 
%
root.name = 'G';
root.apply = @(x,dt) ruleCreateRoot(x,p,1,dt);

%
% set up root crown
%
rules = getTurtle;
rules.BranchRotate.delta = atan(rand^ce*cr);
rules.PitchU.delta=pi/2;
crown = [{rules.PitchU},{rules.Push},{rules.BranchRotate}, root, {rules.Pop}];
for i=1:nobr-1;
    rules.BranchRotate.delta = atan(rand^ce*cr);
    crown = [crown,{rules.Push}, {rules.BranchRotate}, root, {rules.Pop}];
end

%
% set up root system
%
walk.name = 'f';
walk.length = pr;
walk.apply = @(x,dt) {x};

rules.PitchU.delta=pi/2;
rootsystem = [{rules.Push},walk, crown, {rules.Pop}];

for i=1:nop-1;
    rules.TurnL.delta=2*pi/nop;
    rootsystem = [rootsystem,{rules.TurnL},{rules.Push},walk,crown, {rules.Pop}];
end

rootsystem = initLabels(rootsystem);
