function res=getBounds(str, X, Y)
% getBounds: Returns the spatial bounds of an L-System string.
%
% Uses given polylines (X) or segments (X,Y).
%        
% res=getBounds(str):
% str           List of L-System letters
%
% res=getBounds([],X):
% X             Polylines of the root system
%
% res=getBounds([],X,Y):
% X,Y           Start and end points of segments
%
% res           spatial boundaries of the L-System string.
%
% See also: getPolylines, getSegments.
%
% Copyright 2008-2012 Daniel Leitner. See license.txt for details.
%  

if (nargin==1)
    [X,Y] = getSegments(str);
end

if (nargin==2) 
    p1 = min(X{1},[],1);
    p2 = max(X{1},[],1);
    for i=2 : length(X)
        p1=min(min(X{i},[],1),p1);
        p2=max(max(X{i},[],1),p2);    
    end
end  
  
if (nargin==1 ||nargin==3)
    p1 = min(min(X,[],1),min(Y,[],1));
    p2 = max(max(X,[],1),max(Y,[],1));     
end

res = [p1(1),p2(1),p1(2),p2(2),p1(3),p2(3),0,1];   


