function objfun = getTropismObjective(type, p1)
% getTropismObjective: returns objective function for common tropisms
%           
% Chemotropism use the global variables 'concentration' to look up the
% concentration, with global spatial resolution X,Y,Z.
%
% Parameters:
% type      :0 plagio-, 1 gravi-, 2 exo-, 3 chemotropism
% p1        :in case of exotropism: initial direction, in case of
%            chemotropismthe axial resolution dx.
%
% objfun    :objective function for ruleTropismN
%
% See also: ruleTropismN.
%
% Copyright 2012 Daniel Leitner. See license.txt for details.
%

switch type  % 0 plagio, 1 gravi, 2 exo, 3 chemo
    case 0
        objfun = @(beta, alpha, y) testH(beta, alpha, y);                
    case 1
        objfun = @(beta, alpha, y) testZ(beta, alpha, y);
    case 2
        objfun = @(beta, alpha, y) testExo(beta, alpha,y, p1);
    case 3        
        objfun = @(beta, alpha, y) testChemo(beta, alpha,y, p1);
end


% for plagiotropism
function z=testH(r,t,y) 
%roll left
Rhp = [ 1 0 0; 0 cos(r) -sin(r); 0 sin(r) cos(r) ];
R = y.R * Rhp;
%turn
Rum = [ cos(t) sin(t) 0; -sin(t) cos(t) 0; 0 0 1];
R = R * Rum;
z = abs(R(3,1));


% for gravitropism
function z=testZ(r,t,y)
%roll left
Rhp = [ 1 0 0; 0 cos(r) -sin(r); 0 sin(r)  cos(r) ];
R = y.R * Rhp;
%turn
Rum = [ cos(t) sin(t) 0; -sin(t) cos(t) 0; 0 0 1];
R = R * Rum;
z = R(3,1);


% for exotropism
function z=testExo(r,t,y,iR) 
%roll left
Rhp = [ 1 0 0; 0 cos(r) -sin(r) ;0 sin(r) cos(r) ];
R = y.R * Rhp;
%turn
Rum = [ cos(t) sin(t) 0; -sin(t) cos(t) 0; 0 0 1];
R = R * Rum;
s = (R(:,1)'*iR(:,1)) / norm(R(:,1)) / norm(iR(:,1));
z = acos(s);


% for chemotropism
function z=testChemo(r,t,y,dx) 
global concentration;
global X;
global Y;
global Z;
%roll left
Rhp = [ 1 0 0; 0 cos(r) -sin(r) ; 0 sin(r)  cos(r) ] ;
R = y.R * Rhp;
%turn
Rum = [ cos(t) sin(t) 0; -sin(t) cos(t) 0; 0 0 1];
R = R * Rum;
x_ = y.xT+dx*R(:,1);
z = -interp3(X,Y,Z,concentration,x_(2),x_(1),x_(3));



