function str=initLabels(str, initial)
% initLabels: Labels all letters with the name 'G'.
%
% The function adds the following parameters: position x.xT, diameter x.dT,
% color x.cT, and root tip heading x.R. These fields can be updated by the
% production rules using labelTip.
%
% Parameters:
% str                :List of L-System letters to be labeled
% intial             :Initial values (default: initial.xT=[0,0,0],
%                     initial.wT=0.1, initial.cT = [0,1,0],
%                     R=diag([1,1,1]))
% str                :labeled L-System string
%
% See also: labelTip.
%
% Copyright 2008-2012 Daniel Leitner. See license.txt for details.
%

if (nargin<2)
    xT = [ 0; 0; 0];
    dT = 0.1;
    cT = [0, 1, 0];
    tT = 0;
    R = diag([1 1 1]);
else
    xT = initial.xT;
    dT = initial.dT;
    cT = initial.cT;
    tT = initial.tT;
    R = initial.R;
end
Rbk = [ cos(pi) sin(pi) 0; -sin(pi) cos(pi) 0; 0 0 1];
stkPtr = 1;

for i=1:length(str)
    
    switch str{i}.name
        case '#'
            dT = str{i}.width;
        case 'C'
            cT = str{i}.color;
        case {'F','f'}
            lenF = str{i}.length;
            xT = xT + lenF*R(:,1);
        case 'G'
            str{i}.xT=xT;
            str{i}.dT=dT;
            str{i}.cT=cT;
            str{i}.tT=tT;
            str{i}.R=R;
        case '+'
            a = str{i}.delta;
            R = R * [ cos(a) sin(a) 0; -sin(a) cos(a) 0; 0 0 1 ];
        case '-'
            a = str{i}.delta;
            R = R * [ cos(-a) sin(-a) 0; -sin(-a) cos(-a) 0; 0 0 1 ];
        case '&'
            a = str{i}.delta;
            R = R * [ cos(a) 0  -sin(a) ; 0 1 0; sin(a) 0 cos(a) ];
        case '^'
            a = str{i}.delta;
            R = R * [ cos(-a) 0 -sin(-a) ; 0 1 0; sin(-a) 0 cos(-a)];
        case '\'
            a = str{i}.delta;
            R = R * [ 1 0 0; 0 cos(a) -sin(a) ; 0 sin(a)  cos(a) ] ;
        case '/'
            a = str{i}.delta;
            R = R * [ 1 0 0; 0 cos(-a) -sin(-a) ; 0 sin(-a) cos(-a) ];
        case '|'
            R = R * Rbk;
        case '[' %push the stack
            stack(stkPtr).xT = xT ;
            stack(stkPtr).dT = dT;
            stack(stkPtr).cT = cT;
            stack(stkPtr).R = R;
            stkPtr = stkPtr +1 ;
            
        case ']' %pop the stack
            stkPtr = stkPtr -1;
            xT = stack(stkPtr).xT ;
            dT = stack(stkPtr).dT;
            cT = stack(stkPtr).cT;
            R = stack(stkPtr).R;
    end
    
end

