function x=labelTip(x,str,dt)
% labelTip: Updates the position, diameter, color and heading of a letter x.
%
% The uptdate is performed by applying the turtle commands given in str.
%        
% Parameters:     
% x         :updates the parameters: position x.xT, diameter x.dT, color
%            x.cT, and root tip heading x.R 
% str       :list of L-System letters that may change tip postion and
%            heading  
%
% x         :the labeled letter x.
%
% See also: initLabels.
%
% Copyright 2008-2012 Daniel Leitner. See license.txt for details.
%

Rbk = [ cos(pi) sin(pi) 0; -sin(pi) cos(pi) 0; 0 0 1];

% Initialize the turtle
xT = x.xT;
dT = x.dT;
cT = x.cT;
tT = x.tT+dt;
R = x.R;

stkPtr = 1;

for i=1:length(str)

    switch str{i}.name
        case '#'
            dT = str{i}.width;
        case 'C'
            cT = str{i}.color;
        case {'F', 'G','f'}
            lenF = str{i}.length;
            xT = xT + lenF*R(:,1);
        case '+'
            a = str{i}.delta;
            R = R * [ cos(a) sin(a) 0; -sin(a) cos(a) 0; 0 0 1 ];
        case '-'
            a = str{i}.delta;
            R = R * [ cos(-a) sin(-a) 0; -sin(-a) cos(-a) 0; 0 0 1 ];
        case '&'
            a = str{i}.delta;
            R = R * [ cos(a) 0  -sin(a) ; 0 1 0; sin(a) 0 cos(a) ];
        case '^'
            a = str{i}.delta;
            R = R * [ cos(-a) 0 -sin(-a) ; 0 1 0; sin(-a) 0 cos(-a)];
        case '\'
            a = str{i}.delta;
            R = R * [ 1 0 0; 0 cos(a) -sin(a) ; 0 sin(a)  cos(a) ] ;
        case '/'
            a = str{i}.delta;
            R = R * [ 1 0 0; 0 cos(-a) -sin(-a) ; 0 sin(-a) cos(-a) ];
        case '|'
            R = R * Rbk;
        case '[' %push the stack
            stack(stkPtr).xT = xT ;
            stack(stkPtr).dT = dT;
            stack(stkPtr).cT = cT;
            stack(stkPtr).R = R;
            stkPtr = stkPtr +1 ;

        case ']' %pop the stack
            stkPtr = stkPtr -1;
            xT = stack(stkPtr).xT ;
            dT = stack(stkPtr).dT;
            cT = stack(stkPtr).cT;
            R = stack(stkPtr).R;
    end

end

x.xT=xT;
x.dT=dT;
x.cT=cT;
x.tT=tT;
x.R=R;


