function makeMovie(name,str,p,simtime,movietime, fview)
% animate: Creates an animation and stores it in an .avi movie file.
%
% Parameters:
% name          :filename
% str           :list of initial L-System letters; or precomputed slides
% p             :a list of parameter sets (for each root type)
% simtime       :simulation time (in days)
% movietime     :length of the movie (in seconds)
% fview         :callback function after the figure is drawn (default:
%                @(frame) view(0,0)) 
%
% See also: plotTubes, completeParams, simulate.
%
% Copyright 2012 Daniel Leitner. See license.txt for details.
%

if nargin<6
    fview = @(frame) view(0,0);
end

yy = 1080;
p = completeParams(p);

if iscell(str{1}) %precomputed
    slides = str; % rename
    nof = length(slides);
    FPS = round(nof/movietime); % approximate fps
else % initial string
    FPS = 24;
    nof = movietime*FPS; % nubmer of frames    
    slides = simulate(str,simtime,nof,true);
end

inc = 0.05; %percent
bounds = getBounds(slides{end});
bounds(1) = bounds(1) - inc*(bounds(2)-bounds(1)); % x
bounds(2) = bounds(2) + inc*(bounds(2)-bounds(1));
bounds(3) = bounds(3) - inc*(bounds(4)-bounds(3)); % y
bounds(4) = bounds(4) + inc*(bounds(4)-bounds(3));
bounds(5) = bounds(5) - inc*(bounds(6)-bounds(5)); % y
bounds(6) = bounds(6) + inc*(bounds(6)-bounds(5));

% movie resolution
xx = round((yy/(bounds(6)-bounds(5)))*(bounds(2)-bounds(1)));

% precompute geometry boundaries
if ~isempty(p{1}.geometry) 
    X = linspace(bounds(1),bounds(2),50);
    Y = linspace(bounds(3),bounds(4),50);
    Z = linspace(bounds(5),bounds(6),50);
    [geom, n] = plotDistFunc(p{1}.geometry,X,Y,Z);
else
    geom = [];
end

fig = figure();
set(fig,'Position',[10 60 xx yy])
frames(1:nof) = getframe(fig); %preallocate
aviobj = avifile (name,'fps',FPS); %iyuv %i420 
close(fig);

for i = 1 : nof

    disp([ 'framenumber: ' num2str(i) ]);
    fig = figure();
    clf;
    title(['Time: ' num2str((i/nof)*simtime,2) ' days']);
    daspect([1 1 1])
    set(fig,'Position',[10 60 xx yy]) 
    set(fig,'DoubleBuffer','on');    
    %
    plotTubes(slides{i}); 
    hold on;
    if ~isempty(geom)
        p=patch(geom);
        set(p,'VertexNormals',n);
        set(p,'FaceColor',[0,0,1],'EdgeColor','none');
        alpha(p,0.2);
    end
        
    %
    axis(bounds);
    axis equal;
    fview(i); % callback function for figure view
   
    % capture frame
    pause(1);        
    frames(i) = getframe(fig);
    aviobj = addframe ( aviobj, frames(i) );
    close(fig);

end

aviobj = close(aviobj);

