function [fv,n] = plotDistFunc(f,x,y,z,color,isovalue)
% plotDistFunc: plots a signed distance function.
%
% Parameters:
% f             :signed distance function of the geometry
% x             :resolution of the x-axis
% y             :resolution of the y-axis
% z             :resolution of the z-axis
% (color)       :color of the isosurface (default='blue')
% (isovalue)    :isovalue (default=0) 
%
% fv            :faces and vertices of the isosurface
% n             :normals of the vertices
%
% See also: distPot, distRhizotron.
%
% Copyright 2008-2012 Daniel Leitner. See license.txt for details.
%   

if (nargin<5)
    color='blue';
end

if (nargin<6)
    isovalue=0;
end

[X,Y,Z] = meshgrid(x,y,z);
a = size(X,1);
b = size(X,2);
c = size(X,3);
n = a*b*c;
X = reshape(X,n,1,1);
Y = reshape(Y,n,1,1);
Z = reshape(Z,n,1,1);
V = f([X Y Z]);
V = reshape(V, a, b, c);

fv = isosurface(x,y,z,V,isovalue);
p = patch(fv);
n = isonormals(x,y,z,V,p);
set(p,'FaceColor',color,'EdgeColor','none');
daspect([1 1 1])
view(3); axis tight;
camlight ;
lighting gouraud
alpha(p,0.2);

