function plotTubes(lines,diameters,colors,Nsides)
% plotTubes: Plots a roots system using stream tubes
%
% plotTubes(str)
% str             :L-System string
%
% plotTubes(lines,widths,colors,Nsides)
% lines           :a list of polylines given by a vector of points
% diameters       :a list of diameters.
% colors          :a list of colors
% (Nsides)        :The number of points along the circumference of the
%       tube. Default Nsides=7.
%
% See also: getPolylines, plotLines.
%
% Copyright 2008-2012 Daniel Leitner. See license.txt for details.
%

if (nargin==1)
    [lines,diameters,colors] = getPolylines(lines);
end

if (nargin<4)
    Nsides=7;
end

diameters2 = cell(length(lines),1);
for i = 1 : length(lines)
    diameters2{i}= ones(1,size(lines{i},1))*diameters(i);
end

hsF=streamtube(lines,diameters2,[1,Nsides]);

% delete empty roots 
c=1;
for i = 1 : length(lines)
    if size(lines{i},1)==1
        colors(c)=[];
    else
        c=c+1;
    end
end

% draw tubes
for i=1 : length(hsF)
    hsfp{i} = get(hsF(i));
    nodes = size(hsfp{i}.ZData,1);
    cd = cat(3,ones(nodes,Nsides+1),ones(nodes,Nsides+1),ones(nodes,Nsides+1));    
    cd(1,:,1) = colors{i}(1,1);
    cd(1,:,2) = colors{i}(1,2);
    cd(1,:,3) = colors{i}(1,3);
    for j=2:size(cd,1)
        cd(j,:,1) = colors{i}(j-1,1);
        cd(j,:,2) = colors{i}(j-1,2);
        cd(j,:,3) = colors{i}(j-1,3);
    end    
    set(hsF(i),'CData',cd)
end

axis equal;
bnd = getBounds([],lines);
bnd = bnd + [0,0.01,0,0.01,0,0.01,0,0];
axis(bnd);
view(0,0)
shading interp;
camlight; % doesnt work with slices
lighting gouraud;
rotate3d on


