function new = ruleBranch(x,lambda,times,delays,branch,next,tropism,rlt,dx,dt,p)
% ruleBranch: Production rule for the branching zone of a root.
%
% Parameters:
% x         :labelled letter that is replaced by this rule. letter 'x' must
%           have a field x.c with the current number of branches. 
% lambda    :growth function lambda
% times     :creation and terminal times of branches 
% delays    :delay times for delayed growth of branches
% branch    :initial string containing a branch
% next      :successive string (after the branching zone)
% tropism   :production rule describing root tropism
% rlt       :root life time
% dx        :spatial discretization along the root
% dt        :time step
%
% new       :resulting string
%
% See also: ruleCreateRoot, ruleDelay, ruleSectionGrowth.
%
% Copyright 2008-2012 Daniel Leitner. See license.txt for details.
%

x.c=x.c+1;
nob = length(delays);

% Segment
s.name = 'G';
s.t = 0;
s.l = 0;
s.xT = x.xT;
s.dT = x.dT;
s.cT = x.cT;
s.tT = x.tT;
s.R = x.R;
if (x.c<nob)    
    s.apply = @(y,dt) ruleSectionGrowth(y,lambda,...
        lambda(times(x.c),s),lambda(times(x.c+1),s), times(x.c),times(x.c+1),x,tropism,rlt,dx,dt);
else
    s.apply = @(y,dt) ruleSectionGrowth(y,lambda,...
        lambda(times(x.c),s),lambda(times(x.c+1),s), times(x.c),times(x.c+1),next,tropism,rlt,dx,dt);
end

% Delayed Branch
delay.name='w';
delay.t = 0;
delay.xT = x.xT;
delay.dT = x.dT;
delay.cT = x.cT;
delay.tT = x.tT;
delay.R = x.R;
delay.apply = @(y,dt) ruleDelay(y,delays(x.c),branch,dt,p);

delay = delay.apply(delay,dt);
s = s.apply(s,dt);

new = [delay, s];

