function new = ruleDelay(x,tend,next,dt,p)
% ruleDelay: Replaces the letter with a 'next' after a time delay.
%
% Parameters:
% x        :labelled letter that is replaced by this rule. letter 'x' must
%           have a field x.t with its local age. 
% tend     :time delay
% next     :an array [number of successing root type, propability; ...] or
%           an initial string of the successor.
% dt       :time step
% p        :list of root parameters for each root type
%
% new      :resulting string
%
% See also: ruleCreateRoot. 
%
% Copyright 2008-2012 Daniel Leitner. See license.txt for details.
%

if (x.t+dt>tend) % finished
        
    if ~isstruct(next) 
        
        if isempty(next)
            i = 1;            
        elseif size(next,2) == 1 % one successor
            i = 1;
        else % more than one possible successor                      
            sr = [0; cumsum(next(:,2)); 1];
            i = sum(rand()>sr);           
        end 
        
        if i<=size(next,1)
            ind = next(i,1);
            new = ruleCreateRoot(x,p,ind,x.t+dt-tend);
        else         
            new= {};
        end
              
    else  
        
        next.xT = x.xT;
        next.dT = x.dT;
        next.cT = x.cT;
        next.tT = x.tT;
        next.R = x.R;
        new = applyRules({next},x.t+dt-tend);
        
    end
        
else % do nothing

    x.t = x.t+dt;
    x.tT = x.tT+dt;
    new = {x};

end



