function new = ruleRestrictTropism(y,dx,geometry,tropism)
% ruleBoundDeflection: Spatially bounds the root tip movement.
%
% Parametrs:
% y         :labelled lettter (containg position x.xT, diameter x.dT, color
%            x.cT, and root tip heading x.R)
% dx        :next segments length 
% geometry  :distance function of the geometry that bounds the domain
% tropism   :tropism rule 
%
% new       :resulting string containing rotations
%
% See also: ruleCreateRoot, ruleTropismN, Example_Rhizotron
%
% Copyright 2008-2012 Daniel Leitner. See license.txt for details.
%

word = tropism(y,dx);
beta = word{1}.delta;
alpha = word{2}.delta;
d = geometry(testAlphaBeta(alpha,beta,y,dx));

i=0;
dmin=inf;
while (d>0)
    i=i+1;
    %try beta
    j=0;
    while d>0 && j<5;
        beta = 2*pi*rand;
        d = geometry(testAlphaBeta(alpha,beta,y,dx));
        if (d<dmin)
            dmin=d;
            bestA = alpha;
            bestB = beta;
        end
        j=j+1;
    end
    %increase alpha
    if d>0
        alpha=alpha + pi/20*alpha/abs(alpha);
    end
    if i>20
        disp('Could not respect boundaries');
        disp(dmin);
        alpha=bestA;
        beta=bestB;
        break
    end
end

% Create rules
r.name = '\';
r.delta = beta;
t.name = '+';
t.delta = alpha;
new = [{r},{t}];

function x=testAlphaBeta(alpha,beta,y,dx)
alpha=-alpha;
%roll left
Rhp = [ 1 0 0; 0 cos(beta) -sin(beta); 0 sin(beta) cos(beta) ] ;
R = y.R * Rhp;
%turn
Rum = [ cos(-alpha) sin(-alpha) 0; -sin(-alpha) cos(-alpha) 0; 0 0 1 ];
R = R * Rum;
x(1,1:3) = y.xT + dx*R(:,1);



