function new = ruleSectionGrowth(x,lambda,l0,lend,t0,tend,next,tropism,rlt,dx,dt)
% ruleSectionGrowth: Describes root growth within a section.
%
% Parameters:
% x         :labelled letter that is replaced by this rule. letter 'x' must
%            have a field x.t with its local age and x.l with its local
%            length. 
% lambda    :growth function lambda(t)
% l0        :length at creation time
% lend      :length at terminal time
% t0        :creation time
% tend      :terminal time
% next      :successive string
% tropism   :production rule describing root tropism
% rlt       :root life time
% dx        :spatial discretization along the root
% dt        :time step
%
% new       :resulting string
%
% See also: ruleCreateRoot, ruleBranch.
%
% Copyright 2008-2012 Daniel Leitner. See license.txt for details.
%

ls = lend-l0;
A=min(l0+x.l+dx,lend) <= lambda(t0+x.t+dt,x);

if x.t < rlt
    
    if  A && (x.l+dx < ls) % new segments
        
        f.name='F';
        f.length=dx;
        f.time = x.tT;
        x.l = x.l + dx;
        bend = tropism(x,dx);
        x = labelTip(x,[bend, {f}], 0); % use something faster
        new = [bend, {f}, x.apply(x,dt) ];
        
    elseif A && (x.l+dx >= ls) % end
        
        lr = ls-x.l;
        ct = t0 + x.t + dt - tend; % Initialize 'next' with ct
        
        if (lr>0)
            f.name = 'F';
            f.length=lr;
            f.time = x.tT;
            bend = tropism(x,lr);
            x=labelTip(x,[bend,{f}],0);
            next.xT = x.xT;
            next.dT = x.dT;
            next.cT = x.cT;
            next.tT = x.tT+dt-ct;
            next.R = x.R;
            new = [bend,{f},next.apply(next,ct)];
        else
            next.xT = x.xT;
            next.dT = x.dT;
            next.cT = x.cT;
            next.tT = x.tT+dt-ct;
            next.R = x.R;
            new=next.apply(next,ct);
        end
        
    else % do nothing (increase time)
        
        x.t = x.t+dt;
        x.tT=x.tT+dt;
        new = {x};
        
    end
    
else   % branch is dead and stops growing
    f.name = 'F';
    f.length=0;
    f.time = x.tT;
    new={f};
end
