function new = ruleTropismN(y,N,sigma,dx,objfun)
% ruleTropism: tip favours headings where objfun becomes small.
%
% Parameters:
% y         :labelled lettter (containg position x.xT, diameter x.dT, color
%            x.cT, and root tip heading x.R)
% N         :N random tries to find best heading
% sigma     :random noise in angular movement
% dx        :spatial discretization along the root axis
% objfun    :objfun(alpha,beta,y) objective function to minimize
%
% new       :resulting string
%
% See also: getTropismObjective, restrictTropism
%
% Copyright 2008-2012 Daniel Leitner. See license.txt for details.
%

% find heading
if N>0
    
    N = N * sqrt(dx);
    dn = N-floor(N);
    if dn>0
        if rand()<dn
            N=ceil(N);
        else
            N=floor(N);
        end
    end
    
    rr = rand*2*pi;
    tt = sigma*randn*sqrt(dx);
    zm = objfun(rr,tt,y);
    
    for i=1:N
        beta = rand*2*pi;
        alpha = sigma*randn*sqrt(dx);
        z=objfun(beta,alpha,y);
        if (z<zm) 
            zm=z;
            rr=beta;
            tt=alpha;
        end
    end
    beta = rr;
    alpha = tt;
    
else
    
    beta = pi-rand*2*pi;
    alpha =sigma*randn*sqrt(dx);
    
end

% Create rules
r.name = '\';
r.delta = beta;
t.name = '+';
t.delta = alpha;
new = [{r},{t}];

