function res=simulate(str,simtime,nof,keep,init)
% simulate: Starts a simulation run.
%
% Parameters:
% str        :initial L-System string
% simtime    :simulation time
% (nof)      :number of intermediate results (default nof=1)
% (keep)     :keep intermediate results (default keep=true)
% (init)     :initialize labels (default = true), if you continue a
%             simulation the value must be set to false
%
% res       :list of resulting strings
%
% See also: applyRules.
%
% Copyright 2008-2009 Daniel Leitner. See license.txt for details.
%

if (nargin<3) 
    nof=1;
end;

if (nargin<4)
    keep=true;
end

if (nargin<5)
    init=true;
end

dt = simtime/nof;
if keep
    res = cell(1,nof);
end

str = applyRules(str,0);   
if init
    str = initLabels(str); %provides the letters with position and heading
end

active = getActive(str,0); %finds the non-static letters

tic
for i = 1 : nof
    disp([num2str(i) ': ' num2str(length(active)) ' / ' num2str(length(str))]);
    [str,active] = applyRules(str,dt,active);
    if keep
        res{i}=str;   
    end
end
toc

if (~keep)
    res{1}=str;
end

